﻿--
-- This is the LockBox Locktools file where Locktools functions will go
--
DEFAULT_CHAT_FRAME:AddMessage("LockBoxTools.lua loaded.",1,0,0);
--[[

  Originally written by Dustin J. Wilson
  Last update 21 February, 2006

  Modified and Expanded for use in LockBox by LazySumo 3/2006

--]]

LOCKTOOLS_VERSION = 1.5

local localInCombat
local localInMelee
local isPetAttacking
local usingWand = 0;
local LockTools_startup_message = "|CFF0042FFLockTools Warlock Functions v1.5 loaded."
local LockTools_VariablesLoaded = nil;


function LB_LockTools_msg(msg)
  DEFAULT_CHAT_FRAME:AddMessage(msg);
end

--Internal function that returns the SpellID of the highest ranking spell for SpellName
--Written by Andrew Young(andrew@inmyroom.org)
function LB_LTGetSpellID(SpellName)
  local SpellCount = 0
  local ReturnName
  while (SpellName ~= ReturnName) do
    SpellCount = SpellCount + 1
    ReturnName = GetSpellName(SpellCount, BOOKTYPE_SPELL)
  end
  while (SpellName == ReturnName) do
    SpellID = SpellCount
    SpellCount = SpellCount + 1
    ReturnName = GetSpellName(SpellCount, BOOKTYPE_SPELL)    
    if (SpellName ~= ReturnName) then
      break
    end
  end
  return SpellID
end

--Will print a msg at the top of the screen.
function LB_Locktools_TOS(msg)
  UIErrorsFrame:AddMessage(msg, 1, 1, 1, 1, 1);
end

--Internal function that loops through all debuffs looking for a name match
function LB_LockTools_checkDebuff(buff)
  local counter = 1
  while (UnitDebuff("target", counter)) do
    debuff = UnitDebuff("target", counter)
    if (string.find(debuff, buff)) then
      return true
    end
    counter = counter + 1
  end
  return false
end

--Loops through all of the buffs currently active looking for a string match
function LB_LockTools_locationBuff(buff) 
  local active = false
  local counter = 1
  while (UnitBuff("player", counter)) do
    if (string.find(UnitBuff("player", counter), buff)) then
      active = true
      break
    end
    counter = counter + 1
  end
  return active
end


function LB_isCorruption()
  return LB_LockTools_checkDebuff("Spell_Shadow_AbominationExplosion")
end

function LB_castCorruption()
  local SpellName = "Corruption"
  local Debuff= "Spell_Shadow_AbominationExplosion"
  local SpellID = LB_LTGetSpellID(SpellName)
  if (not LB_LockTools_checkDebuff(Debuff)) then
    CastSpell(SpellID, 0)
    return true
  else
    return false
  end
end

function LB_isAgony()
  return LB_LockTools_checkDebuff("Spell_Shadow_CurseOfSargeras")
end



function LB_castAgony()
  local SpellName = "Curse of Agony"
  local Debuff= "Spell_Shadow_CurseOfSargeras"
  local SpellID = LB_LTGetSpellID(SpellName)
  if (not LB_LockTools_checkDebuff(Debuff)) then
    CastSpell(SpellID, 0)
    return true
  else
    return false
  end
end


function LB_isWeakness()
  return LB_LockTools_checkDebuff("Spell_Shadow_CurseOfMannoroth")
end


function LB_castWeakness()
  local SpellName = "Curse of Weakness"
  local Debuff= "Spell_Shadow_CurseOfMannoroth"
  local SpellID = LB_LTGetSpellID(SpellName)
  if (not LB_LockTools_checkDebuff(Debuff)) then
    CastSpell(SpellID, 0)
    return true
  else
    return false
  end
end


function LB_isImmolate()
  return LB_LockTools_checkDebuff("Spell_Fire_Immolation")
end

function LB_castImmolate()
  local SpellName = "Immolate"
  local Debuff= "Spell_Fire_Immolation"
  local SpellID = LB_LTGetSpellID(SpellName)
  if (not LB_LockTools_checkDebuff(Debuff)) then
    CastSpell(SpellID, 0)
    return true
  else
    return false
  end
end

function LB_isSoulDrain()
  return LB_LockTools_checkDebuff("Spell_Shadow_Haunting")
end

function LB_castSoulDrain()
  local SpellName = "Drain Soul"
  local Debuff= "Spell_Shadow_Haunting"
  local SpellID = LB_LTGetSpellID(SpellName)
  if (not LB_LockTools_checkDebuff(Debuff)) then
    CastSpell(SpellID, 0)
    return true
  else
    return false
  end
end

function LB_isSeduced()
	return LB_LockTools_checkDebuff("Seduction")
end

function LB_SoulShards()
	SoulShard = 0;
  for bag=0,4 do
    for slot=1,GetContainerNumSlots(bag) do
      if (GetContainerItemLink(bag,slot)) then
        if (string.find(GetContainerItemLink(bag,slot), "Soul Shard")) then
          SoulShard = SoulShard+1;
        end
      end
    end
  end
  return SoulShard
end

function LB_isCoS()
  return LB_LockTools_checkDebuff("Spell_Shadow_CurseOfAchimonde")
end

function LB_castCoS()
  local SpellName = "Curse of Shadow"
  local Debuff= "Spell_Shadow_CurseOfAchimonde"
  local SpellID = LB_LTGetSpellID(SpellName)
  if (not LB_LockTools_checkDebuff(Debuff)) then
    CastSpell(SpellID, 0)
    return true
  else
    return false
  end
end

function LB_isCoE()
  return LB_LockTools_checkDebuff("Spell_Shadow_ChillTouch")
end

function LB_castCoE()
  local SpellName = "Curse of the Elements"
  local Debuff= "Spell_Shadow_ChillTouch"
  local SpellID = LB_LTGetSpellID(SpellName)
  if (not LB_LockTools_checkDebuff(Debuff)) then
    CastSpell(SpellID, 0)
    return true
  else
    return false
  end
end

function LB_isCoT()
  return LB_LockTools_checkDebuff("Spell_Shadow_CurseOfTounges")
end

function LB_castCoT()
  local SpellName = "Curse of Tongues"
  local Debuff= "Spell_Shadow_CurseOfTounges"
  local SpellID = LB_LTGetSpellID(SpellName)
  if (not LB_LockTools_checkDebuff(Debuff)) then
    CastSpell(SpellID, 0)
    return true
  else
    return false
  end
end

function LB_isCoR()
  return LB_LockTools_checkDebuff("Spell_Shadow_UnholyStrength")
end

function LB_castCoR()
  local SpellName = "Curse of Recklessness"
  local Debuff= "Spell_Shadow_UnholyStrength"
  local SpellID = LB_LTGetSpellID(SpellName)
  if (not LB_LockTools_checkDebuff(Debuff)) then
    CastSpell(SpellID, 0)
    return true
  else
    return false
  end
end

function LB_isCoEx()
  return LB_LockTools_checkDebuff("Spell_Shadow_GrimWard")
end

function LB_castCoEx()
  local SpellName = "Curse of Exhaustion"
  local Debuff= "Spell_Shadow_GrimWard"
  local SpellID = LB_LTGetSpellID(SpellName)
  if (not LB_LockTools_checkDebuff(Debuff)) then
    CastSpell(SpellID, 0)
    return true
  else
    return false
  end
end

function isBanish()
  return LB_LockTools_checkDebuff("Shadow_Cripple")
end

function castBanish()
  local SpellName = "Banish"
  local Debuff= "Shadow_Cripple"
  local SpellID = LB_LTGetSpellID(SpellName)
  if (not LB_LockTools_checkDebuff(Debuff)) then
    CastSpell(SpellID, 0)
    return true
  else
    return false
  end
end

-- 11/28/2005 DJW
-- Adding Calls to check for SIPHON LIFE and to cast it

function LB_isSiphonLife()
  return LB_LockTools_checkDebuff("Spell_Shadow_Requiem")
end

function LB_castSiphonLife()
  local SpellName = "Siphon Life"
  local Debuff= "Spell_Shadow_Requiem"
  local SpellID = LB_LTGetSpellID(SpellName)
  if (not LB_LockTools_checkDebuff(Debuff)) then
    CastSpell(SpellID, 0)
    return true
  else
    return false
  end
end

-- 12/12/2005 DJW
-- Adding calls to check for DRAIN LIFE and to cast it

function LB_isDrainLife()
  return LB_LockTools_checkDebuff("Spell_Shadow_LifeDrain02")
end

function LB_castDrainLife()
  local SpellName = "Drain Life"
  local Debuff= "Spell_Shadow_LifeDrain02"
  local SpellID = LB_LTGetSpellID(SpellName)
  if (not LB_LockTools_checkDebuff(Debuff)) then
    CastSpell(SpellID, 0)
    return true
  else
    return false
  end
end


function LB_castDeathCoil()
  local SpellName = "Death Coil"
  local SpellID = LB_LTGetSpellID(SpellName)
  LTcheckCoolThenCast(spellID)
end

-- 12/12/2005 DJW
-- Adding call to cast FEAR

function LB_castFear()
  local SpellName = "Fear"
  local SpellID = LB_LTGetSpellID(SpellName)
  CastSpell(SpellID, 0)
end

-- 12/12/2005 DJW
-- Adding call to cast DRAIN MANA

function LB_castDrainMana()
  local SpellName = "Drain Mana"
  local SpellID = LB_LTGetSpellID(SpellName)
  CastSpell(SpellID, 0)
end

-- 12/12/2005 DJW
-- Adding call to cast LIFE TAP

function LB_castLifeTap()
  local SpellName = "Life Tap"
  local SpellID = LB_LTGetSpellID(SpellName)
  CastSpell(SpellID, 0)
end

function LB_UseHealthStone()
	for LB_bag=0,4 do
		for LB_slot=1,GetContainerNumSlots(LB_bag) do
			if (GetContainerItemLink(LB_bag,LB_slot)) then
				if (string.find(GetContainerItemLink(LB_bag,LB_slot), "Healthstone")) then
					if GetContainerItemCooldown(LB_bag,LB_slot) == 0 then
						UseContainerItem(LB_bag, LB_slot);
						ActionTaken = 1;
					end
				end 	
			end
		end
	end
end


function LB_IsHealthStoneAvail()
	for LB_bag=0,4 do
    for LB_slot=1,GetContainerNumSlots(LB_bag) do
      if (GetContainerItemLink(LB_bag,LB_slot)) then
        if (string.find(GetContainerItemLink(LB_bag,LB_slot), "Healthstone")) then
			return true
        end
      end
    end
  end
end


-- 12/12/2005 DJW
-- Adding call to cast LIFE TAP

function LB_castShadowBolt()
  local SpellName = "Shadow Bolt"
  local SpellID = LB_LTGetSpellID(SpellName)
	CastSpell(SpellID, 0)
end


--DJW Added 02/21/2006
--Command to stop spellcasting
--Adding to setup Keybind
function LTStopCasting()
	SpellStopCasting();
end

--DJW Added 02/23/2006
--Command to check for Nightfall
--Special Thanks to Coralai from Curse-Gaming.com
function LB_isNightFall()
	local Buff = "Spell_Shadow_Twilight"
	if (LB_LockTools_locationBuff(Buff)) then
		return true
	else
		return false
	end
end


--Internal function that loops through all debuffs looking for a name match
function DebuffCheck()
  local counter = 1
  while (UnitDebuff("target", counter)) do
    debuff = UnitDebuff("target", counter)
    DEFAULT_CHAT_FRAME:AddMessage(debuff,0,1,0);
    counter = counter + 1
  end
  return false
end


function castAmpCur()

	local SpellName = "Amplify Curse"
	local SpellID = LB_LTGetSpellID(SpellName)
	if (not LTcheckCoolThenCast(SpellID)) then 
		return true
	else 
		return false
	end

end

function LB_SpellDump()
	for id = 1, 180, 1	do 
		local spellName
		subSpellName = GetSpellName(id, SpellBookFrame.bookType);
		ChatFrame1:AddMessage(id..": "..subSpellName, 1.0, 1.0, 0.5); 
	end;
end

function LB_PetAttack()

	if UnitAffectingCombat("pet") then
		LB_Locktools_TOS("They're pissed")
	else
		LB_Locktools_TOS("Future uncertain")
	end
	LB_Locktools_TOS(UnitName("pet").." has a class of "..UnitClass("pet").." and a family of "..UnitCreatureFamily("pet") )
	 
end